const layout = () => (
  <Form color="#000000">
      {/*
    Duplicate CalSTRS template in Docspring - Template folder
    Replace stamp ID with new Docspring template ID
    Enter workflow information
    
     */}
      <Section>
        <Boolean
          id="showInstructions"
          text="Check this box to show instructions at the bottom of the form."
        />
        <Computed
          id="submittedByName"
          label="Submitter Name"
          display="false"
          formula="`${firstName} ${lastName}`"
        />
      </Section>
      <Group id="header">
        <Section>
          <Text columns={4}>
            <h3>Permissive Membership</h3>
            <p>ES 0350 REV 04/23</p>
          </Text>
          <Image
            src="https://demo1.api.droplet.io/v1/assets/drplt-fi-p-jEOAgJ-BYkGNY-GJYr23MyL9FQ6rJnBQklfDAxjQK-1043-250.png"
            width={80}
            columns={3}
          />
          <Tile columns={5}>
            <Image
              src="https://api.droplet.io/v1/assets/drplt-fi-p-9WlEAa-gy7mqK-vzkKkBz6rJSV8EE5rl31TQzXqpLG-465-108.png"
              align="right"
              width={60}
            />
            <Text>
              <div style={{ fontSize: 12, textAlign: "right" }}>
                <p>
                  California State Teachers' Retirement System
                  <br />
                  P.O. Box 15275, MS 17
                  <br />
                  Sacramento, CA 95851-0275
                  <br />
                  800-228-5453
                  <br />
                  <a href="https://www.calstrs.com/" target="_blank">
                    CalSTRS.com
                  </a>
                </p>
              </div>
            </Text>
          </Tile>
        </Section>
      </Group>
      <Section
        id="rejectedReasonSubmitter"
        wide={false}
        display="typeof _reason !== 'undefined' && currentStep() === 'restart'"
        background="#FAFAFA"
      >
        <Text>
          <div style={{ fontSize: 18, color: "#FF0000" }}>
            Your submission requires corrections. Please address the following
            issues to proceed:
            <br />
            <br />
            <i>##_reason##</i>
          </div>
        </Text>
      </Section>
      <Section>
        <Text columns={9}>
          <p>
            <b>
              PERMISSIVE MEMBERSHIP ELECTION AND/OR ACKNOWLEDGEMENT OF RECEIPT OF
              CALSTRS DEFINED BENEFIT PROGRAM MEMBERSHIP INFORMATION
            </b>
          </p>
        </Text>
        <Line color="#000000" weight={2} />
        <Text>
          <p>
            This form is used to permissively elect membership in the CalSTRS
            Defined Benefit Program and/or to acknowledge receipt of information
            provided by an employer about the right to elect membership in the
            CalSTRS Defined Benefit Program. Please read all instructions before
            completing the form.
          </p>
        </Text>
        <Line color="#000000" weight={2} />
      </Section>
      <Section>
        <Text marginBottom={-5}>
          <div style={{ fontWeight: "bold", fontSize: 20 }}>
            Section 1: Employee Information (to be completed by employee)
          </div>
        </Text>
        <Text>
          Provide either your CalSTRS Client ID or Social Security number.
        </Text>
        <Radio
          id="idChoice"
          columns={6}
          options={[{ client: "Client ID" }, { ssn: "Social Security Number" }]}
          horizontal
          initialValue="client"
        />
        <Input
          id="clientId"
          label="Client ID"
          columns={6}
          display="idChoice === 'client'"
        />
        <Input
          id="socialSecurityNumber"
          mask="/{social}"
          clear
          guide
          label="Social Security Number"
          columns={6}
          display="idChoice === 'ssn'"
        />
      </Section>
      <Section>
        <Input id="lastName" label="Last Name" columns={5} />
        <Input id="firstName" label="First Name" columns={5} />
        <Input id="mi" label="MI" columns={2} />
      </Section>
      <Section>
        <Input
          id="address"
          label="Address (number, street, apt or suite no.)"
          columns={12}
        />
        <Input id="city" label="City" columns={4} />
        <Dropdown
          id="state"
          label="State:"
          columns={2}
          options={[
            "AK",
            "AL",
            "AR",
            "AS",
            "AZ",
            "CA",
            "CO",
            "CT",
            "DC",
            "DE",
            "FL",
            "GA",
            "GU",
            "HI",
            "IA",
            "ID",
            "IL",
            "IN",
            "KS",
            "KY",
            "LA",
            "MA",
            "MD",
            "ME",
            "MI",
            "MN",
            "MO",
            "MS",
            "MT",
            "NC",
            "ND",
            "NE",
            "NH",
            "NJ",
            "NM",
            "NV",
            "NY",
            "OH",
            "OK",
            "OR",
            "PA",
            "PR",
            "RI",
            "SC",
            "SD",
            "TN",
            "TX",
            "UT",
            "VA",
            "VI",
            "VT",
            "WA",
            "WI",
            "WV",
            "WY",
          ]}
          initialValue="CA"
        />
        <Input
          id="zip"
          mask="/(5)9"
          guide
          label="Zip:"
          columns={3}
          placeholder="_____"
        />
        <Datetime id="dateOfBirth" type="date" label="Date of Birth" columns={3} />
      </Section>
      <Section>
        <Input
          id="submittedByEmail"
          type="email"
          label="Email Address"
          columns={8}
        />
        <Input
          id="phone"
          mask="/{phone}"
          guide
          label="Telephone:"
          columns={4}
          placeholder="(___)___-____"
        />
        <Line color="#000000" weight={2} />
      </Section>
      <Section>
        <Text marginBottom={-5}>
          <div style={{ fontWeight: "bold", fontSize: 20 }}>
            Section 2: Employee Election (to be completed by employee)
          </div>
        </Text>
        <Text>Check One:</Text>
      </Section>
      <Section>
        <Tile columns={9}>
          <Radio
            id="election"
            options={[
              {
                accept:
                  "I elect membership in the CalSTRS Defined Benefit Program as of:",
              },
              {
                decline:
                  "I decline membership in the CalSTRS Defined Benefit Program at this time",
              },
            ]}
          />
        </Tile>
        <Datetime
          id="membershipDate"
          type="date"
          label="Membership Date"
          columns={3}
          display="election == 'accept'"
          validate="currentStep() === 'start' ? isOptional() : isRequired(value)"
        />
      </Section>
      <Section>
        <Text display="election == 'accept'">
          <div style={{ fontWeight: "bold", color: "#DF3225" }}>
            <p>
              I understand this election applies to all future creditable service
              performed for any current or future employer unless another election
              is made as allowed by law. I understand my membership is irrevocable
              and may only be cancelled by terminating all employment to perform
              creditable service and receiving a refund of my accumulated retirement
              contributions from the CalSTRS Defined Benefit Program.
            </p>
            <p>
              **Membership Date may be no earlier than the first day of the pay
              period in which the election is made, or the first day of employment,
              whichever is later.{" "}
              <u>
                Please work with your employer to select the most beneficial, valid
                membership date.
              </u>
            </p>
          </div>
        </Text>
        <Text display="election == 'decline'">
          <div style={{ fontWeight: "bold", color: "#DF3225" }}>
            I understand that I can elect membership in the CalSTRS Defined Benefit
            Program at any time while I am employed to perform creditable service.
          </div>
        </Text>
        <Line color="#000000" weight={2} />
      </Section>
      <Section>
        <Text marginBottom={-5}>
          <div style={{ fontWeight: "bold", fontSize: 20 }}>
            Section 3: Required Signature (to be completed by employee)
          </div>
        </Text>
        <Text columns={12}>
          <p>
            I certify that I have received information from my employer concerning
            the CalSTRS Defined Benefit Program and understand the criteria for
            membership in the program.
          </p>
          <p>
            {" "}
            I understand it is a crime to fail to disclose a material fact or to
            make any knowingly false material statement, including a false statement
            regarding my marital status, for the purpose of using it, or allowing it
            to be used, to obtain, receive, continue, increase, deny or reduce any
            benefit administered by CalSTRS and it may result in penalties,
            including restitution, of up to one year in jail and/or a fine of up to
            $5,000 (Education Code section 22010). It may also result in any
            document containing such false representation being voided. I certify
            under penalty of perjury under the laws of the State of California that
            the foregoing is true and correct. I understand that perjury is
            punishable by imprisonment for up to four years (Penal Code section
            126).
          </p>
        </Text>
        <Signature
          id="signature"
          label="Employee Signature:"
          columns={8}
          validate="signature.toLowerCase() === submittedByName.toLowerCase()"
        />
        <Timestamp
          id="signatureDate"
          label="Date:"
          columns={4}
          display="signature"
        />
      </Section>
      <Group id="officeSections">
        <Line color="#000000" weight={2} />
        <Section>
          <Text marginBottom={-5}>
            <div style={{ fontWeight: "bold", fontSize: 20 }}>
              Section 4: Employee Position Information (to be completed by employer)
            </div>
          </Text>
          <Input
            id="positionTitle"
            hint="If you do not know, leave blank"
            label="Position Title"
            columns={6}
            validate="true"
          />
          <Datetime
            id="positionHireDate"
            hint="If you do not know, leave blank"
            type="date"
            label="Position Hire Date"
            columns={6}
            validate="true"
          />
          <Line color="#000000" weight={2} />
        </Section>
        <Section>
          <Text marginBottom={-5}>
            <div style={{ fontWeight: "bold", fontSize: 20 }}>
              Section 5: Employer Information and Certification (to be completed by
              employer)
            </div>
          </Text>
          <Text>
            <b>Required Signature</b>
          </Text>
          <Text columns={12}>
            <p>
              I certify that the above-named employee was provided information about
              their right to elect membership in the CalSTRS Defined Benefit Program
              and, if electing membership, is eligible to elect membership in the
              CalSTRS Defined Benefit Program as of the membership date provided.
            </p>
            <p>
              I understand it is a crime to fail to disclose a material fact or to
              make any knowingly false material statement for the purpose of using
              it, or allowing it to be used, to obtain, receive, continue, increase,
              deny or reduce any benefit administered by CalSTRS and it may result
              in penalties, including restitution, of up to one year in jail and/or
              a fine of up to $5,000 (Education Code section 22010). It may also
              result in any document containing such false representation being
              voided. I certify under penalty of perjury under the laws of the State
              of California that the foregoing is true and correct. I understand
              that perjury is punishable by imprisonment for up to four years (Penal
              Code section 126).
            </p>
          </Text>
        </Section>
        <Section>
          <Signature
            id="employerOfficialsSignature"
            label="Employer Officials's Signature"
            columns={6}
          />
          <Timestamp
            id="employerOfficialsDate"
            label="Date"
            columns={6}
            display="employerOfficialsSignature"
          />
        </Section>
        <Section>
          <Input id="employerName" label="Employer Name" columns={6} />
          <Input
            id="countyAndDistrictCode"
            label="County and District Code"
            columns={6}
          />
        </Section>
        <Section>
          <Input
            id="employerOfficialsNmeAndTitle"
            label="Employer Offical's Name and Title"
            columns={6}
          />
        </Section>
      </Group>
      <Section>
        <Stamp
          id="stamp"
          label="Stamped PDF"
          columns={6}
          display="['officeStep', 'completed'].includes(currentStep())"
          filename="##submittedByName##—CalSTRS"
          template="REPLACE ME"
        />
      </Section>
      <Actions />
      <Section display="showInstructions">
        <Text>
          <div style={{ fontWeight: "bold" }}>INSTRUCTIONS</div>
        </Text>
        <Line color="#000000" weight={2} />
        <Tile columns={6}>
          <Text>
            <p>
              If you are employed to perform creditable service in a position that
              is excluded from mandatory membership in the CalSTRS’ Defined Benefit
              (DB) Program, you may use this form to elect DB Program membership at
              any time while employed to perform creditable service.
            </p>
            <p>
              A permissive election of membership in the DB Program applies to all
              future creditable service performed for the same or another employer,
              including any non-member or CalSTRS Cash Balance Benefit (CB) Program
              service you are currently performing. You may be entitled to elect
              coverage by the CB Program or California Public Employees’ Retirement
              System (CalPERS) for future eligible service as allowed by law. Please
              work with your employer if you believe you are entitled to make one of
              these elections.
            </p>
            <p>
              A permissive election of membership in the DB Program is irrevocable.
              Membership may only be cancelled if you terminate all employment to
              perform creditable service and refund your accumulated retirement
              contributions from the CalSTRS DB Program.
            </p>
            <p>
              <b>SECTION 1: EMPLOYEE INFORMATION</b>
              <br />
              <b>(TO BE COMPLETED BY EMPLOYEE)</b>
            </p>
            <p>
              Provide the following information:
              <br />• CalSTRS Client ID* or Social Security Number
              <br />• Last Name, First Name and Middle Initial
              <br />• Mailing Address**, City, State and Zip Code
              <br />• Date of Birth
              <br />• Email Address
              <br />• Telephone Number
            </p>
            <p>
              *If you have already been employed to perform creditable service you
              will have a CalSTRS Client ID, even if you were not formerly a member.
              Please provide your CalSTRS Client ID, if you have one, in lieu of
              your Social Security Number.
            </p>
            <p>
              **To establish residency for tax purposes, we ask that you provide a
              street address. Be sure to include any street, apartment or suite
              number. If your post office does not deliver mail to your street
              address, you may enter your box number instead. If you reside outside
              the United States, use the CITY – STATE – ZIP field to provide your
              foreign address. If you receive your mail in care of a third party,
              enter “c/o” followed by the third party’s name and address.
            </p>
          </Text>
        </Tile>
        <Tile columns={6}>
          <Text>
            <p>
              <b>SECTION 2: EMPLOYEE ELECTION</b>
              <br />
              <b>(TO BE COMPLETED BY EMPLOYEE)</b>
            </p>
            <p>
              If you want to elect membership in the CalSTRS DB Program:
              <br />• Check the appropriate box
              <br />• Provide your requested membership date***
            </p>
            <p>
              ***You will begin contributing to the DB Program as of your membership
              date. Your membership date can be no earlier than the first day of the
              pay period in which your election is made, or your first day of
              employment, whichever is later. Work with your employer to select the
              most beneficial, valid membership date you are eligible for. Electing
              an invalid membership date will require a revision to your election
              form and may result in delayed contributions to CalSTRS.
            </p>
            <p>
              If you do not want to elect membership in the CalSTRS DB Program at
              this time, check the appropriate box.
            </p>
            <p>
              <b>SECTION 3: REQUIRED SIGNATURE</b>
              <br />
              <b>(TO BE COMPLETED BY EMPLOYEE)</b>
            </p>
            <p>
              Sign the form and date your signature. Return the form to your
              employer.
            </p>
            <p>
              <b>SECTION 4: EMPLOYEE POSITION INFORMATION</b>
              <br />
              <b>(TO BE COMPLETED BY EMPLOYER)</b>
            </p>
            <p>
              Provide the position hire date – the date in which the employee was
              hired to perform creditable service in the position they are making
              this election for. CalSTRS defers to the employer as to the date in
              which you consider an employee to be hired. Provide the position title
              – the title of the position the employee is performing creditable
              service in.
            </p>
            <p>
              <b>SECTION 5: EMPLOYER INFORMATION AND CERTIFICATION</b>
              <br />
              <b>(TO BE COMPLETED BY EMPLOYER)</b>
            </p>
            <p>
              Verify the employee is eligible for the requested membership date.
            </p>
            <p>
              Provide the following information:
              <br />• The employer (county or district) name
              <br />• County and district code
              <br />• Name and title of employer official completing the form
            </p>
            <p>
              Sign the form and date your signature. Submit the form to CalSTRS and
              retain a copy.
            </p>
          </Text>
        </Tile>
        <Line color="#000000" weight={2} />
        <Tile columns={6}>
          <Text>
            <p>
              <b>SUBMIT</b>
            </p>
            <p>
              This form should be submitted to CalSTRS by the employer. CalSTRS must
              receive this form within 60 days after the employee’s signature date
              and, if applicable, prior to the submission of contributions.
            </p>
            <p>
              Secure Employer Website:
              <br />
              Send the completed form to the ES Forms Queue found in the Business
              Areas dropdown of the Recipient via SEW.
            </p>
            <p>
              Email to:
              <br />
              Submit this form via email to the esforms@calstrs.com mailbox unless
              otherwise instructed by your CalSTRS representative. If sending forms
              to the esforms@calstrs.com mailbox, please remove all Social Security
              numbers and only provide the Client ID where applicable.
            </p>
            <p>
              Mail to:
              <br />
              CalSTRS P.O. Box 15275, MS 17 Sacramento, CA 95851-0275
            </p>
            <p>
              <b>QUESTIONS</b>
              <br />
              Employee – contact your employer
              <br />
              Employer – contact CalSTRS Employer Help
            </p>
          </Text>
        </Tile>
      </Section>
    </Form>
);

// -------
// Exports
// -------

export { layout };
